loki_logger library
Classes
- ConsoleOutput
- Outputs logs to the console
- DevelopmentFilter
- Default filter that only shows logs in debug mode
- LevelFilter
- Filter that shows logs based on minimum level
- LogEvent
- Represents a log event with all relevant information
- LogFilter
- Interface for filtering log events
- LogOutput
- Interface for outputting log lines
- LogPrinter
- Interface for formatting log events into strings
- LokiClient
- LokiConfig
- Configuration for LokiLogger to connect to Loki Server and send logs.
- LokiLogger
- Main logger class that brings together filter, printer, and output
- PrettyPrinter
- Pretty printer with colors and formatting
- SimplePrinter
- Simple printer that outputs the log message
Enums
- Level
- Log levels based on severity